
# Changelog
All notable changes to Corporal will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.1.2] - 2021-06-15
### Changed
- More fabric tweaks for basic Corporal app install.
- Remove version restriction for mysql-connector-python.

## [0.1.1] - 2021-06-11
### Changed
- Freeze sqlalchemy version per pip issues

## [0.1.0] - 2021-06-11
### Added
- Initial release, to test install
